

CREATE TABLE akt_prawny (
    ap_id integer NOT NULL,
    fop_id integer NOT NULL,
    rodzaj_aktu_id smallint,
    link character varying(128),
    plik character varying(128),
    miejsce_pub text,
    oznaczenie text,
    nazwa text,
    kolejnosc smallint,
    data_pub date
);


ALTER TABLE public.akt_prawny OWNER TO postgres;

--
-- Name: akt_prawny_ap_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE akt_prawny_ap_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.akt_prawny_ap_id_seq OWNER TO postgres;

--
-- Name: akt_prawny_ap_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE akt_prawny_ap_id_seq OWNED BY akt_prawny.ap_id;


--
-- Name: fop; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE fop (
    fop_id integer NOT NULL,
    typ_formy_id smallint,
    archiwalny boolean,
    zatwierdzony boolean,
    roboczy boolean,
    nazwa character varying(256),
    opis text,
    data_utworzenia date,
    opis_granicy text,
    geom_granicy text,
    epsg_granicy smallint,
    konwencja boolean,
    powierzchnia numeric(12,4),
    nadzorca character varying(256),
    geom geometry,
    inspire_id character varying(32),
    guid uuid,
    zniesiony boolean,
    CONSTRAINT enforce_dims_geom CHECK ((st_ndims(geom) = 2)),
    CONSTRAINT enforce_srid_geom CHECK ((st_srid(geom) = 2180))
);


ALTER TABLE public.fop OWNER TO postgres;

--
-- Name: fop_archiwum; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE fop_archiwum (
    fa_id integer NOT NULL,
    fop_id integer NOT NULL,
    kod_organu character varying(8) NOT NULL,
    uzytkownik character varying(32),
    data_operacji timestamp without time zone,
    rodzaj_operacji character varying(32),
    zmiany text,
    uwagi text
);


ALTER TABLE public.fop_archiwum OWNER TO postgres;

--
-- Name: fop_archiwum_fa_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE fop_archiwum_fa_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.fop_archiwum_fa_id_seq OWNER TO postgres;

--
-- Name: fop_archiwum_fa_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE fop_archiwum_fa_id_seq OWNED BY fop_archiwum.fa_id;


--
-- Name: fop_edycja; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE fop_edycja (
    fe_id integer NOT NULL,
    fop_id integer NOT NULL,
    kod_organu character varying(8),
    dokument_id character varying(32),
    imie_nazwisko character varying(64),
    adres_email character varying(64),
    nr_telefonu character varying(32),
    uwagi text,
    data_wprowadzenia date,
    data_modyfikacji date
);


ALTER TABLE public.fop_edycja OWNER TO postgres;

--
-- Name: fop_edycja_fe_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE fop_edycja_fe_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.fop_edycja_fe_id_seq OWNER TO postgres;

--
-- Name: fop_edycja_fe_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE fop_edycja_fe_id_seq OWNED BY fop_edycja.fe_id;


--
-- Name: fop_fop_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE fop_fop_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.fop_fop_id_seq OWNER TO postgres;

--
-- Name: fop_fop_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE fop_fop_id_seq OWNED BY fop.fop_id;


--
-- Name: fop_gmina; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE fop_gmina (
    fg_fop_id_k integer NOT NULL,
    fg_gm_id_k integer NOT NULL
);


ALTER TABLE public.fop_gmina OWNER TO postgres;

--
-- Name: fop_material_zrodlowy; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE fop_material_zrodlowy (
    fop_id integer NOT NULL,
    material_zrodlowy_id smallint NOT NULL,
    rodzaj_geometrii_id character varying(2) NOT NULL
);


ALTER TABLE public.fop_material_zrodlowy OWNER TO postgres;

--
-- Name: fop_organ; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE fop_organ (
    fop_id integer NOT NULL,
    kod_organu character varying(8) NOT NULL
);


ALTER TABLE public.fop_organ OWNER TO postgres;

--
-- Name: gmina; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE gmina (
    gm_id_s integer NOT NULL,
    nazwa character varying(64),
    gm_po_id_k integer,
    gm_rodzaj_c character varying(64)
);


ALTER TABLE public.gmina OWNER TO postgres;

--
-- Name: gmina_gm_id_s_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE gmina_gm_id_s_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.gmina_gm_id_s_seq OWNER TO postgres;

--
-- Name: gmina_gm_id_s_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE gmina_gm_id_s_seq OWNED BY gmina.gm_id_s;


--
-- Name: kategoria_stan; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE kategoria_stan (
    kategoria_stan_id smallint NOT NULL,
    nazwa character varying(32)
);


ALTER TABLE public.kategoria_stan OWNER TO postgres;

--
-- Name: konwencja; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE konwencja (
    ko_id integer NOT NULL,
    fop_id integer NOT NULL,
    rodzaj_konw_id smallint,
    opis text,
    rok integer,
    geom geometry,
    geom_text text,
    epsg smallint,
    caly_obszar boolean,
    CONSTRAINT enforce_dims_geom CHECK ((st_ndims(geom) = 2)),
    CONSTRAINT enforce_srid_geom CHECK ((st_srid(geom) = 2180))
);


ALTER TABLE public.konwencja OWNER TO postgres;

--
-- Name: konwencja_ko_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE konwencja_ko_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.konwencja_ko_id_seq OWNER TO postgres;

--
-- Name: konwencja_ko_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE konwencja_ko_id_seq OWNED BY konwencja.ko_id;


--
-- Name: material_zrodlowy; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE material_zrodlowy (
    material_zrodlowy_id smallint NOT NULL,
    nazwa character varying(32),
    rozdzielczosc smallint
);


ALTER TABLE public.material_zrodlowy OWNER TO postgres;

--
-- Name: natura2000; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE natura2000 (
    n2k_id integer NOT NULL,
    fop_id integer NOT NULL,
    kod_n2k character varying(12),
    rodzaj_n2k_id character varying(3),
    plan_ochrony boolean,
    data_planu date,
    zadania_ochronne boolean,
    data_zadan date
);


ALTER TABLE public.natura2000 OWNER TO postgres;

--
-- Name: natura2000_n2k_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE natura2000_n2k_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.natura2000_n2k_id_seq OWNER TO postgres;

--
-- Name: natura2000_n2k_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE natura2000_n2k_id_seq OWNED BY natura2000.n2k_id;


--
-- Name: obszar_chron_krajobrazu; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE obszar_chron_krajobrazu (
    ochk_id integer NOT NULL,
    fop_id integer NOT NULL,
    brak_nazwy boolean,
    wartosc_przyrodnicza text
);


ALTER TABLE public.obszar_chron_krajobrazu OWNER TO postgres;

--
-- Name: obszar_chron_krajobrazu_ochk_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE obszar_chron_krajobrazu_ochk_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.obszar_chron_krajobrazu_ochk_id_seq OWNER TO postgres;

--
-- Name: obszar_chron_krajobrazu_ochk_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE obszar_chron_krajobrazu_ochk_id_seq OWNED BY obszar_chron_krajobrazu.ochk_id;


--
-- Name: obszar_ochrony; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE obszar_ochrony (
    oo_id integer NOT NULL,
    fop_id integer NOT NULL,
    rodzaj_ochrony_id character varying(2),
    powierzchnia_och numeric(12,4),
    geom_granicy_och text,
    epsg smallint,
    caly_obszar boolean,
    geom geometry,
    CONSTRAINT enforce_dims_geom CHECK ((st_ndims(geom) = 2)),
    CONSTRAINT enforce_geotype_geom CHECK (((geometrytype(geom) = 'MULTIPOLYGON'::text) OR (geom IS NULL))),
    CONSTRAINT enforce_srid_geom CHECK ((st_srid(geom) = 2180))
);


ALTER TABLE public.obszar_ochrony OWNER TO postgres;

--
-- Name: obszar_ochrony_oo_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE obszar_ochrony_oo_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.obszar_ochrony_oo_id_seq OWNER TO postgres;

--
-- Name: obszar_ochrony_oo_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE obszar_ochrony_oo_id_seq OWNED BY obszar_ochrony.oo_id;


--
-- Name: park_krajobrazowy; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE park_krajobrazowy (
    pk_id integer NOT NULL,
    fop_id integer NOT NULL,
    otulina boolean,
    powierzchnia_ot numeric(12,4),
    opis_granicy_ot text,
    geom_granicy_ot text,
    epsg_granicy_ot smallint,
    plan_ochrony boolean,
    data_planu date,
    cel_ochrony text,
    geom_ot geometry,
    CONSTRAINT enforce_dims_geom_ot CHECK ((st_ndims(geom_ot) = 2)),
    CONSTRAINT enforce_geotype_geom_ot CHECK (((geometrytype(geom_ot) = 'MULTIPOLYGON'::text) OR (geom_ot IS NULL))),
    CONSTRAINT enforce_srid_geom_ot CHECK ((st_srid(geom_ot) = 2180))
);


ALTER TABLE public.park_krajobrazowy OWNER TO postgres;

--
-- Name: park_krajobrazowy_pk_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE park_krajobrazowy_pk_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.park_krajobrazowy_pk_id_seq OWNER TO postgres;

--
-- Name: park_krajobrazowy_pk_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE park_krajobrazowy_pk_id_seq OWNED BY park_krajobrazowy.pk_id;


--
-- Name: park_narodowy; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE park_narodowy (
    pn_id integer NOT NULL,
    fop_id integer NOT NULL,
    otulina boolean,
    powierzchnia_ot numeric(12,4),
    opis_granicy_ot text,
    geom_granicy_ot text,
    epsg_granicy_ot smallint,
    plan_ochrony boolean,
    data_planu date,
    zadania_ochronne boolean,
    data_zadan date,
    geom_ot geometry,
    CONSTRAINT enforce_dims_geom_ot CHECK ((st_ndims(geom_ot) = 2)),
    CONSTRAINT enforce_geotype_geom_ot CHECK (((geometrytype(geom_ot) = 'MULTIPOLYGON'::text) OR (geom_ot IS NULL))),
    CONSTRAINT enforce_srid_geom_ot CHECK ((st_srid(geom_ot) = 2180))
);


ALTER TABLE public.park_narodowy OWNER TO postgres;

--
-- Name: park_narodowy_pn_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE park_narodowy_pn_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.park_narodowy_pn_id_seq OWNER TO postgres;

--
-- Name: park_narodowy_pn_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE park_narodowy_pn_id_seq OWNED BY park_narodowy.pn_id;


--
-- Name: permission; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE permission (
    permission_id integer NOT NULL,
    url character varying(64)
);


ALTER TABLE public.permission OWNER TO postgres;

--
-- Name: permission_permission_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE permission_permission_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.permission_permission_id_seq OWNER TO postgres;

--
-- Name: permission_permission_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE permission_permission_id_seq OWNED BY permission.permission_id;


--
-- Name: podtyp_ekosystemu; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE podtyp_ekosystemu (
    podtyp_ekosystemu_id character varying(3) NOT NULL,
    typ_ekosystemu_id character varying(3),
    nazwa character varying(64)
);


ALTER TABLE public.podtyp_ekosystemu OWNER TO postgres;

--
-- Name: podtyp_ochrony; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE podtyp_ochrony (
    podtyp_ochrony_id character varying(3) NOT NULL,
    typ_ochrony_id character varying(3),
    nazwa character varying(40)
);


ALTER TABLE public.podtyp_ochrony OWNER TO postgres;

--
-- Name: pomnik_przyrody; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE pomnik_przyrody (
    pp_id integer NOT NULL,
    fop_id integer NOT NULL,
    brak_nazwy boolean,
    skupisko_tworow boolean,
    opis_pomnika text,
    opis_lokalizacji text,
    typ_tworu_id integer
);


ALTER TABLE public.pomnik_przyrody OWNER TO postgres;

--
-- Name: pomnik_przyrody_pp_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE pomnik_przyrody_pp_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.pomnik_przyrody_pp_id_seq OWNER TO postgres;

--
-- Name: pomnik_przyrody_pp_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE pomnik_przyrody_pp_id_seq OWNED BY pomnik_przyrody.pp_id;


--
-- Name: pomoc; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE pomoc (
    info_id character varying(16) NOT NULL,
    info text,
    tooltip text,
    nazwa_formularza character varying(256),
    nazwa_pola character varying(256)
);


ALTER TABLE public.pomoc OWNER TO postgres;

--
-- Name: powiat; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE powiat (
    po_id_s integer NOT NULL,
    nazwa character(64),
    po_wo_id_k integer NOT NULL,
    woj character varying,
    kod character varying(4)
);


ALTER TABLE public.powiat OWNER TO postgres;

--
-- Name: powiat_po_id_s_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE powiat_po_id_s_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.powiat_po_id_s_seq OWNER TO postgres;

--
-- Name: powiat_po_id_s_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE powiat_po_id_s_seq OWNED BY powiat.po_id_s;


--
-- Name: rezerwat_przyrody; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE rezerwat_przyrody (
    rp_id integer NOT NULL,
    fop_id integer NOT NULL,
    rodzaj_rezerwatu_id character varying(2),
    typ_ochrony_id character varying(3),
    podtyp_ochrony_id character varying(3),
    typ_ekosystemu_id character varying(3),
    podtyp_ekosystemu_id character varying(3),
    otulina boolean,
    powierzchnia_ot numeric(12,4),
    opis_granicy_ot text,
    geom_granicy_ot text,
    epsg_granicy_ot smallint,
    plan_ochrony boolean,
    data_planu date,
    zadania_ochronne boolean,
    data_zadan date,
    cel_ochrony text,
    geom_ot geometry,
    CONSTRAINT enforce_dims_geom_ot CHECK ((st_ndims(geom_ot) = 2)),
    CONSTRAINT enforce_geotype_geom_ot CHECK (((geometrytype(geom_ot) = 'MULTIPOLYGON'::text) OR (geom_ot IS NULL))),
    CONSTRAINT enforce_srid_geom_ot CHECK ((st_srid(geom_ot) = 2180))
);


ALTER TABLE public.rezerwat_przyrody OWNER TO postgres;

--
-- Name: rezerwat_przyrody_rp_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE rezerwat_przyrody_rp_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.rezerwat_przyrody_rp_id_seq OWNER TO postgres;

--
-- Name: rezerwat_przyrody_rp_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE rezerwat_przyrody_rp_id_seq OWNED BY rezerwat_przyrody.rp_id;


--
-- Name: rodzaj_aktu; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE rodzaj_aktu (
    rodzaj_aktu_id smallint NOT NULL,
    nazwa character varying(32)
);


ALTER TABLE public.rodzaj_aktu OWNER TO postgres;

--
-- Name: rodzaj_geometrii; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE rodzaj_geometrii (
    rodzaj_geometrii_id character varying(2) NOT NULL,
    nazwa character varying(32)
);


ALTER TABLE public.rodzaj_geometrii OWNER TO postgres;

--
-- Name: rodzaj_konw; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE rodzaj_konw (
    rodzaj_konw_id smallint NOT NULL,
    nazwa character varying(64),
    kolejnosc smallint
);


ALTER TABLE public.rodzaj_konw OWNER TO postgres;

--
-- Name: rodzaj_n2k; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE rodzaj_n2k (
    rodzaj_n2k_id character varying(3) NOT NULL,
    nazwa character varying(32)
);


ALTER TABLE public.rodzaj_n2k OWNER TO postgres;

--
-- Name: rodzaj_ochrony; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE rodzaj_ochrony (
    rodzaj_ochrony_id character varying(2) NOT NULL,
    nazwa character varying(32)
);


ALTER TABLE public.rodzaj_ochrony OWNER TO postgres;

--
-- Name: rodzaj_pomnika; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE rodzaj_pomnika (
    rodzaj_pomnika_id smallint NOT NULL,
    nazwa character varying(32)
);


ALTER TABLE public.rodzaj_pomnika OWNER TO postgres;

--
-- Name: rodzaj_rezerwatu; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE rodzaj_rezerwatu (
    rodzaj_rezerwatu_id character varying(2) NOT NULL,
    nazwa character varying(32)
);


ALTER TABLE public.rodzaj_rezerwatu OWNER TO postgres;

--
-- Name: rodzaj_stan; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE rodzaj_stan (
    rodzaj_stan_id smallint NOT NULL,
    nazwa character varying(32)
);


ALTER TABLE public.rodzaj_stan OWNER TO postgres;

--
-- Name: rodzaj_tworu; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE rodzaj_tworu (
    rodzaj_tworu_id smallint NOT NULL,
    nazwa character varying(32),
    typ_przyrody character(1)
);


ALTER TABLE public.rodzaj_tworu OWNER TO postgres;

--
-- Name: rodzaj_uzytku; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE rodzaj_uzytku (
    rodzaj_uzytku_id smallint NOT NULL,
    nazwa character varying(96)
);


ALTER TABLE public.rodzaj_uzytku OWNER TO postgres;

--
-- Name: role; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE role (
    role_id integer NOT NULL,
    role_name character varying(64)
);


ALTER TABLE public.role OWNER TO postgres;

--
-- Name: role_permission; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE role_permission (
    role_id integer NOT NULL,
    permission_id integer NOT NULL
);


ALTER TABLE public.role_permission OWNER TO postgres;

--
-- Name: role_role_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE role_role_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.role_role_id_seq OWNER TO postgres;

--
-- Name: role_role_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE role_role_id_seq OWNED BY role.role_id;


--
-- Name: stanowisko_dokumentacyjne; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE stanowisko_dokumentacyjne (
    sd_id integer NOT NULL,
    fop_id integer NOT NULL,
    brak_nazwy boolean,
    rodzaj_stan_id smallint,
    kategoria_stan_id smallint,
    cel_ochrony text,
    charakter_geolog text
);


ALTER TABLE public.stanowisko_dokumentacyjne OWNER TO postgres;

--
-- Name: stanowisko_dokumentacyjne_sd_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE stanowisko_dokumentacyjne_sd_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.stanowisko_dokumentacyjne_sd_id_seq OWNER TO postgres;

--
-- Name: stanowisko_dokumentacyjne_sd_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE stanowisko_dokumentacyjne_sd_id_seq OWNED BY stanowisko_dokumentacyjne.sd_id;


--
-- Name: strona; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE strona (
    strona_id character varying(10) NOT NULL,
    nazwa_strony character varying(256),
    tytul_strony character varying(256),
    tresc_strony text
);


ALTER TABLE public.strona OWNER TO postgres;

--
-- Name: twor_przyrody; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE twor_przyrody (
    tp_id integer NOT NULL,
    pp_id integer NOT NULL,
    rodzaj_tworu_id smallint,
    liczba_tworow integer,
    geom geometry,
    geom_text text,
    epsg smallint,
    CONSTRAINT enforce_dims_geom CHECK ((st_ndims(geom) = 2)),
    CONSTRAINT enforce_srid_geom CHECK ((st_srid(geom) = 2180))
);


ALTER TABLE public.twor_przyrody OWNER TO postgres;

--
-- Name: twor_przyrody_tp_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE twor_przyrody_tp_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.twor_przyrody_tp_id_seq OWNER TO postgres;

--
-- Name: twor_przyrody_tp_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE twor_przyrody_tp_id_seq OWNED BY twor_przyrody.tp_id;


--
-- Name: typ_ekosystemu; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE typ_ekosystemu (
    typ_ekosystemu_id character varying(3) NOT NULL,
    nazwa character varying(64)
);


ALTER TABLE public.typ_ekosystemu OWNER TO postgres;

--
-- Name: typ_formy; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE typ_formy (
    typ_formy_id smallint NOT NULL,
    kolejnosc smallint NOT NULL,
    nazwa character varying(32)
);


ALTER TABLE public.typ_formy OWNER TO postgres;

--
-- Name: typ_ochrony; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE typ_ochrony (
    typ_ochrony_id character varying(3) NOT NULL,
    nazwa character varying(32)
);


ALTER TABLE public.typ_ochrony OWNER TO postgres;

--
-- Name: typ_tworu; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE typ_tworu (
    id integer NOT NULL,
    nazwa character varying(16)
);


ALTER TABLE public.typ_tworu OWNER TO postgres;

--
-- Name: user_info; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE user_info (
    uid integer NOT NULL,
    login character varying(32) NOT NULL,
    password character varying,
    county_code_rdos character(2),
    imie character varying(64),
    nazwisko character varying(64)
);


ALTER TABLE public.user_info OWNER TO postgres;

--
-- Name: user_info_uid_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE user_info_uid_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.user_info_uid_seq OWNER TO postgres;

--
-- Name: user_info_uid_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE user_info_uid_seq OWNED BY user_info.uid;


--
-- Name: user_role; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE user_role (
    user_id integer NOT NULL,
    role_id integer NOT NULL
);


ALTER TABLE public.user_role OWNER TO postgres;

--
-- Name: uzytek_ekologiczny; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE uzytek_ekologiczny (
    ue_id integer NOT NULL,
    fop_id integer NOT NULL,
    brak_nazwy boolean,
    rodzaj_uzytku_id smallint,
    cel_ochrony text,
    wartosc_przyrodnicza text
);


ALTER TABLE public.uzytek_ekologiczny OWNER TO postgres;

--
-- Name: uzytek_ekologiczny_ue_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE uzytek_ekologiczny_ue_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.uzytek_ekologiczny_ue_id_seq OWNER TO postgres;

--
-- Name: uzytek_ekologiczny_ue_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE uzytek_ekologiczny_ue_id_seq OWNED BY uzytek_ekologiczny.ue_id;


--
-- Name: zespol_przyr_kraj; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE zespol_przyr_kraj (
    zpk_id integer NOT NULL,
    fop_id integer NOT NULL,
    brak_nazwy boolean,
    cel_ochrony text,
    wartosc_przyrodnicza text
);


ALTER TABLE public.zespol_przyr_kraj OWNER TO postgres;

--
-- Name: zespol_przyr_kraj_zpk_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE zespol_przyr_kraj_zpk_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.zespol_przyr_kraj_zpk_id_seq OWNER TO postgres;

--
-- Name: zespol_przyr_kraj_zpk_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE zespol_przyr_kraj_zpk_id_seq OWNED BY zespol_przyr_kraj.zpk_id;


--
-- Name: ap_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY akt_prawny ALTER COLUMN ap_id SET DEFAULT nextval('akt_prawny_ap_id_seq'::regclass);


--
-- Name: fop_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY fop ALTER COLUMN fop_id SET DEFAULT nextval('fop_fop_id_seq'::regclass);


--
-- Name: fa_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY fop_archiwum ALTER COLUMN fa_id SET DEFAULT nextval('fop_archiwum_fa_id_seq'::regclass);


--
-- Name: fe_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY fop_edycja ALTER COLUMN fe_id SET DEFAULT nextval('fop_edycja_fe_id_seq'::regclass);


--
-- Name: gm_id_s; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY gmina ALTER COLUMN gm_id_s SET DEFAULT nextval('gmina_gm_id_s_seq'::regclass);


--
-- Name: ko_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY konwencja ALTER COLUMN ko_id SET DEFAULT nextval('konwencja_ko_id_seq'::regclass);


--
-- Name: n2k_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY natura2000 ALTER COLUMN n2k_id SET DEFAULT nextval('natura2000_n2k_id_seq'::regclass);


--
-- Name: ochk_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY obszar_chron_krajobrazu ALTER COLUMN ochk_id SET DEFAULT nextval('obszar_chron_krajobrazu_ochk_id_seq'::regclass);


--
-- Name: oo_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY obszar_ochrony ALTER COLUMN oo_id SET DEFAULT nextval('obszar_ochrony_oo_id_seq'::regclass);


--
-- Name: pk_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY park_krajobrazowy ALTER COLUMN pk_id SET DEFAULT nextval('park_krajobrazowy_pk_id_seq'::regclass);


--
-- Name: pn_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY park_narodowy ALTER COLUMN pn_id SET DEFAULT nextval('park_narodowy_pn_id_seq'::regclass);


--
-- Name: permission_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY permission ALTER COLUMN permission_id SET DEFAULT nextval('permission_permission_id_seq'::regclass);


--
-- Name: pp_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY pomnik_przyrody ALTER COLUMN pp_id SET DEFAULT nextval('pomnik_przyrody_pp_id_seq'::regclass);


--
-- Name: po_id_s; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY powiat ALTER COLUMN po_id_s SET DEFAULT nextval('powiat_po_id_s_seq'::regclass);


--
-- Name: rp_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY rezerwat_przyrody ALTER COLUMN rp_id SET DEFAULT nextval('rezerwat_przyrody_rp_id_seq'::regclass);


--
-- Name: role_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY role ALTER COLUMN role_id SET DEFAULT nextval('role_role_id_seq'::regclass);


--
-- Name: sd_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY stanowisko_dokumentacyjne ALTER COLUMN sd_id SET DEFAULT nextval('stanowisko_dokumentacyjne_sd_id_seq'::regclass);


--
-- Name: tp_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY twor_przyrody ALTER COLUMN tp_id SET DEFAULT nextval('twor_przyrody_tp_id_seq'::regclass);


--
-- Name: uid; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY user_info ALTER COLUMN uid SET DEFAULT nextval('user_info_uid_seq'::regclass);


--
-- Name: ue_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY uzytek_ekologiczny ALTER COLUMN ue_id SET DEFAULT nextval('uzytek_ekologiczny_ue_id_seq'::regclass);


--
-- Name: zpk_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY zespol_przyr_kraj ALTER COLUMN zpk_id SET DEFAULT nextval('zespol_przyr_kraj_zpk_id_seq'::regclass);


--
-- Name: _akt_prawny_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _akt_prawny
    ADD CONSTRAINT _akt_prawny_pkey PRIMARY KEY (fa_id, ap_id);


--
-- Name: _fop_edycja_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _fop_edycja
    ADD CONSTRAINT _fop_edycja_pkey PRIMARY KEY (fa_id);


--
-- Name: _fop_material_zrodlowy_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _fop_material_zrodlowy
    ADD CONSTRAINT _fop_material_zrodlowy_pkey PRIMARY KEY (fa_id, fop_id, material_zrodlowy_id, rodzaj_geometrii_id);


--
-- Name: _fop_organ_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _fop_organ
    ADD CONSTRAINT _fop_organ_pkey PRIMARY KEY (fa_id, fop_id, kod_organu);


--
-- Name: _fop_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _fop
    ADD CONSTRAINT _fop_pk PRIMARY KEY (fa_id, fop_id);


--
-- Name: _konwencja_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _konwencja
    ADD CONSTRAINT _konwencja_pkey PRIMARY KEY (fa_id, ko_id);


--
-- Name: _natura2000_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _natura2000
    ADD CONSTRAINT _natura2000_pkey PRIMARY KEY (fa_id, n2k_id);


--
-- Name: _obszar_chron_krajobrazu_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _obszar_chron_krajobrazu
    ADD CONSTRAINT _obszar_chron_krajobrazu_pkey PRIMARY KEY (fa_id, ochk_id);


--
-- Name: _obszar_ochrony_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _obszar_ochrony
    ADD CONSTRAINT _obszar_ochrony_pkey PRIMARY KEY (fa_id, oo_id);


--
-- Name: _park_krajobrazowy_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _park_krajobrazowy
    ADD CONSTRAINT _park_krajobrazowy_pkey PRIMARY KEY (fa_id, pk_id);


--
-- Name: _park_narodowy_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _park_narodowy
    ADD CONSTRAINT _park_narodowy_pkey PRIMARY KEY (fa_id, pn_id);


--
-- Name: _pomnik_przyrody_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _pomnik_przyrody
    ADD CONSTRAINT _pomnik_przyrody_pkey PRIMARY KEY (fa_id, pp_id);


--
-- Name: _rezerwat_przyrody_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _rezerwat_przyrody
    ADD CONSTRAINT _rezerwat_przyrody_pkey PRIMARY KEY (fa_id, rp_id);


--
-- Name: _stanowisko_dokumentacyjne_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _stanowisko_dokumentacyjne
    ADD CONSTRAINT _stanowisko_dokumentacyjne_pkey PRIMARY KEY (fa_id, sd_id);


--
-- Name: _twor_przyrody_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _twor_przyrody
    ADD CONSTRAINT _twor_przyrody_pkey PRIMARY KEY (fa_id, tp_id);


--
-- Name: _uzytek_ekologiczny_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _uzytek_ekologiczny
    ADD CONSTRAINT _uzytek_ekologiczny_pkey PRIMARY KEY (fa_id, ue_id);


--
-- Name: _zespol_przyr_kraj_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY _zespol_przyr_kraj
    ADD CONSTRAINT _zespol_przyr_kraj_pkey PRIMARY KEY (fa_id, zpk_id);


--
-- Name: akt_prawny_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY akt_prawny
    ADD CONSTRAINT akt_prawny_pkey PRIMARY KEY (ap_id);


--
-- Name: fop_archiwum_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY fop_archiwum
    ADD CONSTRAINT fop_archiwum_pk PRIMARY KEY (fa_id);


--
-- Name: fop_edycja_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY fop_edycja
    ADD CONSTRAINT fop_edycja_pk PRIMARY KEY (fe_id);


--
-- Name: fop_gmina_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY fop_gmina
    ADD CONSTRAINT fop_gmina_pkey PRIMARY KEY (fg_fop_id_k, fg_gm_id_k);


--
-- Name: fop_material_zrodlowy_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY fop_material_zrodlowy
    ADD CONSTRAINT fop_material_zrodlowy_pkey PRIMARY KEY (fop_id, material_zrodlowy_id, rodzaj_geometrii_id);


--
-- Name: fop_organ_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY fop_organ
    ADD CONSTRAINT fop_organ_pk PRIMARY KEY (fop_id, kod_organu);


--
-- Name: fop_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY fop
    ADD CONSTRAINT fop_pk PRIMARY KEY (fop_id);


--
-- Name: gmina_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY gmina
    ADD CONSTRAINT gmina_pkey PRIMARY KEY (gm_id_s);


--
-- Name: information_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY pomoc
    ADD CONSTRAINT information_pk PRIMARY KEY (info_id);


--
-- Name: kategoria_stan_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY kategoria_stan
    ADD CONSTRAINT kategoria_stan_pk PRIMARY KEY (kategoria_stan_id);


--
-- Name: konwencja_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY konwencja
    ADD CONSTRAINT konwencja_pkey PRIMARY KEY (ko_id);


--
-- Name: material_zrodlowy_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY material_zrodlowy
    ADD CONSTRAINT material_zrodlowy_pkey PRIMARY KEY (material_zrodlowy_id);


--
-- Name: natura2000_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY natura2000
    ADD CONSTRAINT natura2000_pkey PRIMARY KEY (n2k_id);


--
-- Name: obszar_chron_krajobrazu_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY obszar_chron_krajobrazu
    ADD CONSTRAINT obszar_chron_krajobrazu_pkey PRIMARY KEY (ochk_id);


--
-- Name: obszar_ochrony_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY obszar_ochrony
    ADD CONSTRAINT obszar_ochrony_pkey PRIMARY KEY (oo_id);


--
-- Name: park_krajobrazowy_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY park_krajobrazowy
    ADD CONSTRAINT park_krajobrazowy_pkey PRIMARY KEY (pk_id);


--
-- Name: park_narodowy_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY park_narodowy
    ADD CONSTRAINT park_narodowy_pkey PRIMARY KEY (pn_id);


--
-- Name: permission_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY permission
    ADD CONSTRAINT permission_pk PRIMARY KEY (permission_id);


--
-- Name: podtyp_ekosystemu_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY podtyp_ekosystemu
    ADD CONSTRAINT podtyp_ekosystemu_pk PRIMARY KEY (podtyp_ekosystemu_id);


--
-- Name: podtyp_ochrony_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY podtyp_ochrony
    ADD CONSTRAINT podtyp_ochrony_pk PRIMARY KEY (podtyp_ochrony_id);


--
-- Name: pomnik_przyrody_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY pomnik_przyrody
    ADD CONSTRAINT pomnik_przyrody_pkey PRIMARY KEY (pp_id);


--
-- Name: powiat_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY powiat
    ADD CONSTRAINT powiat_pkey PRIMARY KEY (po_id_s);


--
-- Name: rezerwat_przyrody_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY rezerwat_przyrody
    ADD CONSTRAINT rezerwat_przyrody_pkey PRIMARY KEY (rp_id);


--
-- Name: rodzaj_aktu_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY rodzaj_aktu
    ADD CONSTRAINT rodzaj_aktu_pk PRIMARY KEY (rodzaj_aktu_id);


--
-- Name: rodzaj_geometrii_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY rodzaj_geometrii
    ADD CONSTRAINT rodzaj_geometrii_pkey PRIMARY KEY (rodzaj_geometrii_id);


--
-- Name: rodzaj_konw_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY rodzaj_konw
    ADD CONSTRAINT rodzaj_konw_pk PRIMARY KEY (rodzaj_konw_id);


--
-- Name: rodzaj_n2k_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY rodzaj_n2k
    ADD CONSTRAINT rodzaj_n2k_pk PRIMARY KEY (rodzaj_n2k_id);


--
-- Name: rodzaj_ochrony_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY rodzaj_ochrony
    ADD CONSTRAINT rodzaj_ochrony_pk PRIMARY KEY (rodzaj_ochrony_id);


--
-- Name: rodzaj_pomnika_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY rodzaj_pomnika
    ADD CONSTRAINT rodzaj_pomnika_pk PRIMARY KEY (rodzaj_pomnika_id);


--
-- Name: rodzaj_rezerwatu_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY rodzaj_rezerwatu
    ADD CONSTRAINT rodzaj_rezerwatu_pk PRIMARY KEY (rodzaj_rezerwatu_id);


--
-- Name: rodzaj_stan_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY rodzaj_stan
    ADD CONSTRAINT rodzaj_stan_pk PRIMARY KEY (rodzaj_stan_id);


--
-- Name: rodzaj_tworu_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY rodzaj_tworu
    ADD CONSTRAINT rodzaj_tworu_pk PRIMARY KEY (rodzaj_tworu_id);


--
-- Name: rodzaj_uzytku_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY rodzaj_uzytku
    ADD CONSTRAINT rodzaj_uzytku_pk PRIMARY KEY (rodzaj_uzytku_id);


--
-- Name: role_permission_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY role_permission
    ADD CONSTRAINT role_permission_pk PRIMARY KEY (permission_id, role_id);


--
-- Name: role_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY role
    ADD CONSTRAINT role_pk PRIMARY KEY (role_id);


--
-- Name: stanowisko_dokumentacyjne_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY stanowisko_dokumentacyjne
    ADD CONSTRAINT stanowisko_dokumentacyjne_pkey PRIMARY KEY (sd_id);


--
-- Name: strona_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY strona
    ADD CONSTRAINT strona_pkey PRIMARY KEY (strona_id);


--
-- Name: twor_przyrody_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY twor_przyrody
    ADD CONSTRAINT twor_przyrody_pkey PRIMARY KEY (tp_id);


--
-- Name: typ_ekosystemu_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY typ_ekosystemu
    ADD CONSTRAINT typ_ekosystemu_pk PRIMARY KEY (typ_ekosystemu_id);


--
-- Name: typ_formy_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY typ_formy
    ADD CONSTRAINT typ_formy_pk PRIMARY KEY (typ_formy_id);


--
-- Name: typ_ochrony_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY typ_ochrony
    ADD CONSTRAINT typ_ochrony_pk PRIMARY KEY (typ_ochrony_id);


--
-- Name: typ_tworu_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY typ_tworu
    ADD CONSTRAINT typ_tworu_pkey PRIMARY KEY (id);


--
-- Name: user_info_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY user_info
    ADD CONSTRAINT user_info_pk PRIMARY KEY (uid);


--
-- Name: user_role_pk; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY user_role
    ADD CONSTRAINT user_role_pk PRIMARY KEY (user_id, role_id);


--
-- Name: uzytek_ekologiczny_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY uzytek_ekologiczny
    ADD CONSTRAINT uzytek_ekologiczny_pkey PRIMARY KEY (ue_id);


--
-- Name: zespol_przyr_kraj_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY zespol_przyr_kraj
    ADD CONSTRAINT zespol_przyr_kraj_pkey PRIMARY KEY (zpk_id);


--
-- Name: fop_inspire_id_idx; Type: INDEX; Schema: public; Owner: postgres; Tablespace: 
--

CREATE UNIQUE INDEX fop_inspire_id_idx ON fop USING btree (inspire_id);


--
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY gmina
    ADD CONSTRAINT "$1" FOREIGN KEY (gm_po_id_k) REFERENCES powiat(po_id_s);


--
-- Name: _fop_material_zrodlowy_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY _fop_material_zrodlowy
    ADD CONSTRAINT _fop_material_zrodlowy_fkey FOREIGN KEY (material_zrodlowy_id) REFERENCES material_zrodlowy(material_zrodlowy_id);


--
-- Name: _fop_material_zrodlowy_fkey2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY _fop_material_zrodlowy
    ADD CONSTRAINT _fop_material_zrodlowy_fkey2 FOREIGN KEY (rodzaj_geometrii_id) REFERENCES rodzaj_geometrii(rodzaj_geometrii_id);


--
-- Name: _obszar_ochrony_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY _obszar_ochrony
    ADD CONSTRAINT _obszar_ochrony_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: _obszar_ochrony_fkey2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY _obszar_ochrony
    ADD CONSTRAINT _obszar_ochrony_fkey2 FOREIGN KEY (rodzaj_ochrony_id) REFERENCES rodzaj_ochrony(rodzaj_ochrony_id);


--
-- Name: _pomnik_przyrody_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY _pomnik_przyrody
    ADD CONSTRAINT _pomnik_przyrody_fk FOREIGN KEY (typ_tworu_id) REFERENCES typ_tworu(id);


--
-- Name: akt_prawny_fop_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY akt_prawny
    ADD CONSTRAINT akt_prawny_fop_id_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: akt_prawny_rodzaj_aktu_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY akt_prawny
    ADD CONSTRAINT akt_prawny_rodzaj_aktu_id_fkey FOREIGN KEY (rodzaj_aktu_id) REFERENCES rodzaj_aktu(rodzaj_aktu_id);


--
-- Name: fop_edycja_fop_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY fop_edycja
    ADD CONSTRAINT fop_edycja_fop_id_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: fop_material_zrodlowy_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY fop_material_zrodlowy
    ADD CONSTRAINT fop_material_zrodlowy_fkey FOREIGN KEY (material_zrodlowy_id) REFERENCES material_zrodlowy(material_zrodlowy_id);


--
-- Name: fop_material_zrodlowy_fkey2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY fop_material_zrodlowy
    ADD CONSTRAINT fop_material_zrodlowy_fkey2 FOREIGN KEY (rodzaj_geometrii_id) REFERENCES rodzaj_geometrii(rodzaj_geometrii_id);


--
-- Name: fop_organ_fop_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY fop_organ
    ADD CONSTRAINT fop_organ_fop_id_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: fop_typ_formy_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY fop
    ADD CONSTRAINT fop_typ_formy_id_fkey FOREIGN KEY (typ_formy_id) REFERENCES typ_formy(typ_formy_id);


--
-- Name: konwencja_fop_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY konwencja
    ADD CONSTRAINT konwencja_fop_id_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: konwencja_rodzaj_konw_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY konwencja
    ADD CONSTRAINT konwencja_rodzaj_konw_id_fkey FOREIGN KEY (rodzaj_konw_id) REFERENCES rodzaj_konw(rodzaj_konw_id);


--
-- Name: natura2000_fop_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY natura2000
    ADD CONSTRAINT natura2000_fop_id_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: natura2000_rodzaj_n2k_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY natura2000
    ADD CONSTRAINT natura2000_rodzaj_n2k_id_fkey FOREIGN KEY (rodzaj_n2k_id) REFERENCES rodzaj_n2k(rodzaj_n2k_id);


--
-- Name: obszar_chron_krajobrazu_fop_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY obszar_chron_krajobrazu
    ADD CONSTRAINT obszar_chron_krajobrazu_fop_id_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: obszar_ochrony_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY obszar_ochrony
    ADD CONSTRAINT obszar_ochrony_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: obszar_ochrony_fkey2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY obszar_ochrony
    ADD CONSTRAINT obszar_ochrony_fkey2 FOREIGN KEY (rodzaj_ochrony_id) REFERENCES rodzaj_ochrony(rodzaj_ochrony_id);


--
-- Name: park_krajobrazowy_fop_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY park_krajobrazowy
    ADD CONSTRAINT park_krajobrazowy_fop_id_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: park_narodowy_fop_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY park_narodowy
    ADD CONSTRAINT park_narodowy_fop_id_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: pomnik_przyrody_fk; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY pomnik_przyrody
    ADD CONSTRAINT pomnik_przyrody_fk FOREIGN KEY (typ_tworu_id) REFERENCES typ_tworu(id);


--
-- Name: pomnik_przyrody_fop_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY pomnik_przyrody
    ADD CONSTRAINT pomnik_przyrody_fop_id_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: rezerwat_przyrody_fop_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY rezerwat_przyrody
    ADD CONSTRAINT rezerwat_przyrody_fop_id_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: rezerwat_przyrody_podtyp_ekosystemu_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY rezerwat_przyrody
    ADD CONSTRAINT rezerwat_przyrody_podtyp_ekosystemu_id_fkey FOREIGN KEY (podtyp_ekosystemu_id) REFERENCES podtyp_ekosystemu(podtyp_ekosystemu_id);


--
-- Name: rezerwat_przyrody_podtyp_ochrony_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY rezerwat_przyrody
    ADD CONSTRAINT rezerwat_przyrody_podtyp_ochrony_id_fkey FOREIGN KEY (podtyp_ochrony_id) REFERENCES podtyp_ochrony(podtyp_ochrony_id);


--
-- Name: rezerwat_przyrody_rodzaj_rezerwatu_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY rezerwat_przyrody
    ADD CONSTRAINT rezerwat_przyrody_rodzaj_rezerwatu_id_fkey FOREIGN KEY (rodzaj_rezerwatu_id) REFERENCES rodzaj_rezerwatu(rodzaj_rezerwatu_id);


--
-- Name: rezerwat_przyrody_typ_ekosystemu_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY rezerwat_przyrody
    ADD CONSTRAINT rezerwat_przyrody_typ_ekosystemu_id_fkey FOREIGN KEY (typ_ekosystemu_id) REFERENCES typ_ekosystemu(typ_ekosystemu_id);


--
-- Name: rezerwat_przyrody_typ_ochrony_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY rezerwat_przyrody
    ADD CONSTRAINT rezerwat_przyrody_typ_ochrony_id_fkey FOREIGN KEY (typ_ochrony_id) REFERENCES typ_ochrony(typ_ochrony_id);


--
-- Name: role_permission_fk1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY role_permission
    ADD CONSTRAINT role_permission_fk1 FOREIGN KEY (permission_id) REFERENCES permission(permission_id) ON DELETE CASCADE;


--
-- Name: role_permission_fk2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY role_permission
    ADD CONSTRAINT role_permission_fk2 FOREIGN KEY (role_id) REFERENCES role(role_id) ON DELETE CASCADE;


--
-- Name: stanowisko_dokumentacyjne_fop_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY stanowisko_dokumentacyjne
    ADD CONSTRAINT stanowisko_dokumentacyjne_fop_id_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: stanowisko_dokumentacyjne_kategoria_stan_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY stanowisko_dokumentacyjne
    ADD CONSTRAINT stanowisko_dokumentacyjne_kategoria_stan_id_fkey FOREIGN KEY (kategoria_stan_id) REFERENCES kategoria_stan(kategoria_stan_id);


--
-- Name: stanowisko_dokumentacyjne_rodzaj_stan_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY stanowisko_dokumentacyjne
    ADD CONSTRAINT stanowisko_dokumentacyjne_rodzaj_stan_id_fkey FOREIGN KEY (rodzaj_stan_id) REFERENCES rodzaj_stan(rodzaj_stan_id);


--
-- Name: twor_przyrody_pp_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY twor_przyrody
    ADD CONSTRAINT twor_przyrody_pp_id_fkey FOREIGN KEY (pp_id) REFERENCES pomnik_przyrody(pp_id);


--
-- Name: twor_przyrody_rodzaj_tworu_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY twor_przyrody
    ADD CONSTRAINT twor_przyrody_rodzaj_tworu_id_fkey FOREIGN KEY (rodzaj_tworu_id) REFERENCES rodzaj_tworu(rodzaj_tworu_id);


--
-- Name: user_role_fk1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY user_role
    ADD CONSTRAINT user_role_fk1 FOREIGN KEY (user_id) REFERENCES user_info(uid) ON DELETE CASCADE;


--
-- Name: user_role_fk2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY user_role
    ADD CONSTRAINT user_role_fk2 FOREIGN KEY (role_id) REFERENCES role(role_id) ON DELETE CASCADE;


--
-- Name: uzytek_ekologiczny_fop_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY uzytek_ekologiczny
    ADD CONSTRAINT uzytek_ekologiczny_fop_id_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);


--
-- Name: uzytek_ekologiczny_rodzaj_uzytku_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY uzytek_ekologiczny
    ADD CONSTRAINT uzytek_ekologiczny_rodzaj_uzytku_id_fkey FOREIGN KEY (rodzaj_uzytku_id) REFERENCES rodzaj_uzytku(rodzaj_uzytku_id);


--
-- Name: zespol_przyr_kraj_fop_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY zespol_przyr_kraj
    ADD CONSTRAINT zespol_przyr_kraj_fop_id_fkey FOREIGN KEY (fop_id) REFERENCES fop(fop_id);
